#[repr(i32)]pub enum CheckTxType {
New = 0,
Recheck = 1,
}Expand description
Type of transaction check
Variants
New = 0
NEW is the default and means that a full check of the tranasaction is required.
Recheck = 1
RECHECK is used when the mempool is initiating a normal recheck of a transaction.
Implementations
Sourceimpl CheckTxType
impl CheckTxType
Sourceimpl CheckTxType
impl CheckTxType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.