pub struct ExtendVoteExtension {
pub type: i32,
pub extension: Vec<u8>,
pub sign_request_id: Option<Vec<u8>>,
}Expand description
Provides a vote extension for signing. type and extension fields are mandatory for filling
Fields
type: i32Vote extension type can be either DEFAULT, THRESHOLD_RECOVER or THRESHOLD_RECOVER_RAW. The Tenderdash supports only THRESHOLD_RECOVER and THRESHOLD_RECOVER_RAW at this moment.
extension: Vec<u8>Deterministic or (Non-Deterministic) extension provided by the sending validator’s Application.
For THRESHOLD_RECOVER_RAW, it MUST be 32 bytes.
Sign request ID that will be used to sign the vote extensions. Only applicable for THRESHOLD_RECOVER_RAW vote extension type.
Tenderdash will use SHA256 checksum of sign_request_id when generating quorum signatures of
THRESHOLD_RECOVER_RAW vote extensions. It MUST NOT be set for any other vote extension types.
sign_request_id: Option<Vec<u8>>If not set, Tenderdash will generate it based on height and round.
If set, it SHOULD be unique per voting round, and it MUST start with dpevote or \x06plwdtx prefix.
Use with caution - it can have severe security consequences.
Implementations
Sourceimpl ExtendVoteExtension
impl ExtendVoteExtension
Sourcepub fn type(&self) -> VoteExtensionType
pub fn type(&self) -> VoteExtensionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: VoteExtensionType)
pub fn set_type(&mut self, value: VoteExtensionType)
Sets type to the provided enum value.
Sourcepub fn sign_request_id(&self) -> &[u8] ⓘ
pub fn sign_request_id(&self) -> &[u8] ⓘ
Returns the value of sign_request_id, or the default value if sign_request_id is unset.