pub struct Misbehavior {
pub type: i32,
pub validator: Option<Validator>,
pub height: i64,
pub time: Option<Timestamp>,
pub total_voting_power: i64,
}Fields
type: i32validator: Option<Validator>The offending validator
height: i64The height when the offense occurred
time: Option<Timestamp>The corresponding time where the offense occurred
total_voting_power: i64Total voting power of the validator set in case the ABCI application does not store historical validators. https://github.com/tendermint/tendermint/issues/4581
Implementations
Sourceimpl Misbehavior
impl Misbehavior
Sourcepub fn type(&self) -> MisbehaviorType
pub fn type(&self) -> MisbehaviorType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: MisbehaviorType)
pub fn set_type(&mut self, value: MisbehaviorType)
Sets type to the provided enum value.