RequestApplySnapshotChunk

Struct RequestApplySnapshotChunk 

pub struct RequestApplySnapshotChunk {
    pub chunk_id: Vec<u8>,
    pub chunk: Vec<u8>,
    pub sender: String,
}
Applies a snapshot chunk.

  • The application can choose to refetch chunks and/or ban P2P peers as appropriate. Tenderdash will not do this unless instructed by the application.
  • The application may want to verify each chunk, e.g. by attaching chunk hashes in `Snapshot.Metadata`` and/or incrementally verifying contents against AppHash.
  • When all chunks have been accepted, Tenderdash will make an ABCI Info call to verify that LastBlockAppHash and LastBlockHeight matches the expected values, and record the AppVersion in the node state. It then switches to fast sync or consensus and joins the network.
  • If Tenderdash is unable to retrieve the next chunk after some time (e.g. because no suitable peers are available), it will reject the snapshot and try a different one via OfferSnapshot. The application should be prepared to reset and accept it or abort as appropriate.

Fields

chunk_id: Vec<u8>

The chunk index, starting from 0. Tenderdash applies chunks sequentially.

chunk: Vec<u8>

The binary chunk contents, as returned by LoadSnapshotChunk.

sender: String

The P2P ID of the node who sent this chunk.