RequestCheckTx

Struct RequestCheckTx 

pub struct RequestCheckTx {
    pub tx: Vec<u8>,
    pub type: i32,
}
Check if transaction is valid.

  • Technically optional - not involved in processing blocks.
  • Guardian of the mempool: every node runs CheckTx before letting a transaction into its local mempool.
  • The transaction may come from an external user or another node
  • CheckTx validates the transaction against the current state of the application, for example, checking signatures and account balances, but does not apply any of the state changes described in the transaction.
  • Transactions where ResponseCheckTx.Code != 0 will be rejected - they will not be broadcast to other nodes or included in a proposal block.
  • Tendermint attributes no other value to the response code

Fields

tx: Vec<u8>

The request transaction bytes.

type: i32

Type or transaction check to execute.

Implementations

Source

impl RequestCheckTx

pub fn type(&self) -> CheckTxType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: CheckTxType)

Sets type to the provided enum value.