RequestExtendVote

Struct RequestExtendVote 

pub struct RequestExtendVote {
    pub hash: Vec<u8>,
    pub height: i64,
    pub round: i32,
}
Extends a vote with application-side injection

Usage
  • ResponseExtendVote.vote_extensions is optional information that, if present, will be signed by Tenderdash and attached to the Precommit message.
  • RequestExtendVote.hash corresponds to the hash of a proposed block that was made available to the application in a previous call to ProcessProposal or PrepareProposal for the current height.
  • ResponseExtendVote.vote_extensions will only be attached to a non-nil Precommit message. If Tenderdash is to precommit nil, it will not call RequestExtendVote.
  • The Application logic that creates the extensions can be non-deterministic.
When does Tenderdash call it?

When a validator p is in Tenderdash consensus state prevote of round r, height h, in which q is the proposer; and p has received

  • the Proposal message v for round r, height h, along with all the block parts, from q,
  • Prevote messages from 2f + 1 validators’ voting power for round r, height h, prevoting for the same block id(v),

then p’s Tenderdash locks v and sends a Precommit message in the following way

  1. p’s Tenderdash sets lockedValue and validValue to v, and sets lockedRound and validRound to r
  2. p’s Tenderdash calls RequestExtendVote with id(v) (RequestExtendVote.hash). The call is synchronous.
  3. The Application optionally returns an array of bytes, ResponseExtendVote.extension, which is not interpreted by Tenderdash.
  4. p’s Tenderdash includes ResponseExtendVote.extension in a field of type CanonicalVoteExtension, it then populates the other fields in CanonicalVoteExtension, and signs the populated data structure.
  5. p’s Tenderdash constructs and signs the CanonicalVote structure.
  6. p’s Tenderdash constructs the Precommit message (i.e. Vote structure) using CanonicalVoteExtension and CanonicalVote.
  7. p’s Tenderdash broadcasts the Precommit message.

In the cases when p’s Tenderdash is to broadcast precommit nil messages (either 2f+1 prevote nil messages received, or timeoutPrevote triggered), p’s Tenderdash does not call RequestExtendVote and will not include a CanonicalVoteExtension field in the precommit nil message.

Fields

hash: Vec<u8>

The header hash of the proposed block that the vote extensions is to refer to.

height: i64

Height of the proposed block (for sanity check).

round: i32

// Round number for the block.