pub struct RequestVerifyVoteExtension {
pub hash: Vec<u8>,
pub validator_pro_tx_hash: Vec<u8>,
pub height: i64,
pub round: i32,
pub vote_extensions: Vec<ExtendVoteExtension>,
}Expand description
Verify the vote extension
Usage
RequestVerifyVoteExtension.vote_extensioncan be an empty byte array. The Application’s interpretation of it should be that the Application running at the process that sent the vote chose not to extend it. Tenderdash will always callRequestVerifyVoteExtension, even for 0 length vote extensions.- If
ResponseVerifyVoteExtension.statusisREJECT, Tenderdash will reject the whole received vote. See the Requirements section to understand the potential liveness implications of this. - The implementation of
VerifyVoteExtensionMUST be deterministic. Moreover, the value ofResponseVerifyVoteExtension.statusMUST exclusively depend on the parameters passed in the call toRequestVerifyVoteExtension, and the last committed Application state (see Requirements section). - Moreover, application implementers SHOULD always set
ResponseVerifyVoteExtension.statustoACCEPT, unless they really know what the potential liveness implications of returningREJECTare.
When does Tenderdash call it?
When a validator p is in Tenderdash consensus round r, height h, state prevote (TODO discuss: I think I must remove the state from this condition, but not sure), and p receives a Precommit message for round r, height h from q:
- If the Precommit message does not contain a vote extensions with a valid signature, Tenderdash discards the message as invalid.
- a 0-length vote extensions is valid as long as its accompanying signature is also valid.
- Else, p’s Tenderdash calls
RequestVerifyVoteExtension. - The Application returns accept or reject via
ResponseVerifyVoteExtension.status. - If the Application returns
- accept, p’s Tenderdash will keep the received vote, together with its corresponding
vote extension in its internal data structures. It will be used to populate the ExtendedCommitInfo
structure in calls to
RequestPrepareProposal, in rounds of height h + 1 where p is the proposer. - reject, p’s Tenderdash will deem the Precommit message invalid and discard it.
Fields
hash: Vec<u8>The header hash of the propsed block that the vote extensions refers to.
validator_pro_tx_hash: Vec<u8>ProTxHash of the validator that signed the extensions.
height: i64Height of the block (for sanity check).
round: i32// Round number for the block.
vote_extensions: Vec<ExtendVoteExtension>Application-specific information signed by Tenderdash. Can have 0 length.