pub struct ResponseApplySnapshotChunk {
pub result: i32,
pub refetch_chunks: Vec<Vec<u8>>,
pub reject_senders: Vec<String>,
pub next_chunks: Vec<Vec<u8>>,
}Fields
result: i32The result of applying this chunk.
refetch_chunks: Vec<Vec<u8>>Refetch and reapply the given chunks, regardless of result.
Only the listed chunks will be refetched, and reapplied in sequential order.
reject_senders: Vec<String>Reject the given P2P senders, regardless of Result. Any chunks already applied will not be refetched
unless explicitly requested, but queued chunks from these senders will be discarded, and new chunks
or other snapshots rejected.
next_chunks: Vec<Vec<u8>>Next chunks provides the list of chunks that should be requested next, if any.
Implementations