pub struct ResponsePrepareProposal {
pub tx_records: Vec<TxRecord>,
pub app_hash: Vec<u8>,
pub tx_results: Vec<ExecTxResult>,
pub consensus_param_updates: Option<ConsensusParams>,
pub core_chain_lock_update: Option<CoreChainLock>,
pub validator_set_update: Option<ValidatorSetUpdate>,
pub app_version: u64,
}Fields
tx_records: Vec<TxRecord>Possibly modified list of transactions that have been picked as part of the proposed block.
app_hash: Vec<u8>The Merkle root hash of the application state. 32 bytes.
tx_results: Vec<ExecTxResult>List of structures containing the data resulting from executing the transactions.
consensus_param_updates: Option<ConsensusParams>Changes to consensus-critical gas, size, and other parameters that will be applied at next height.
core_chain_lock_update: Option<CoreChainLock>Core chain lock that will be used for next block.
validator_set_update: Option<ValidatorSetUpdate>Changes to validator set that will be applied at next height.
app_version: u64Application version that was used to create the current proposal.