pub struct ValidatorSetUpdate {
pub validator_updates: Vec<ValidatorUpdate>,
pub threshold_public_key: Option<PublicKey>,
pub quorum_hash: Vec<u8>,
}Expand description
ValidatorSetUpdate represents a change in the validator set. It can be used to add, remove, or update a validator.
Validator set update consists of multiple ValidatorUpdate records, each of them can be used to add, remove, or update a validator, according to the following rules:
- If a validator with the same public key already exists in the validator set and power is greater than 0, the existing validator will be updated with the new power.
- If a validator with the same public key already exists in the validator set and power is 0, the existing validator will be removed from the validator set.
- If a validator with the same public key does not exist in the validator set and the power is greater than 0, a new validator will be added to the validator set.
- As a special case, if quorum hash has changed, all existing validators will be removed before applying the new validator set update.
Fields
validator_updates: Vec<ValidatorUpdate>threshold_public_key: Option<PublicKey>quorum_hash: Vec<u8>Trait Implementations
Sourceimpl Clone for ValidatorSetUpdate
impl Clone for ValidatorSetUpdate
Sourcefn clone(&self) -> ValidatorSetUpdate
fn clone(&self) -> ValidatorSetUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorSetUpdate
impl Debug for ValidatorSetUpdate
Sourceimpl Default for ValidatorSetUpdate
impl Default for ValidatorSetUpdate
Sourceimpl<'de> Deserialize<'de> for ValidatorSetUpdate
impl<'de> Deserialize<'de> for ValidatorSetUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ValidatorSetUpdate
impl Message for ValidatorSetUpdate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ValidatorSetUpdate
impl PartialEq for ValidatorSetUpdate
Sourceimpl Serialize for ValidatorSetUpdate
impl Serialize for ValidatorSetUpdate
impl StructuralPartialEq for ValidatorSetUpdate