pub struct RequestExtendVote {
pub hash: Vec<u8>,
pub height: i64,
pub round: i32,
}Expand description
Extends a vote with application-side injection
Usage
ResponseExtendVote.vote_extensionsis optional information that, if present, will be signed by Tenderdash and attached to the Precommit message.RequestExtendVote.hashcorresponds to the hash of a proposed block that was made available to the application in a previous call toProcessProposalorPrepareProposalfor the current height.ResponseExtendVote.vote_extensionswill only be attached to a non-nilPrecommit message. If Tenderdash is to precommitnil, it will not callRequestExtendVote.- The Application logic that creates the extensions can be non-deterministic.
When does Tenderdash call it?
When a validator p is in Tenderdash consensus state prevote of round r, height h, in which q is the proposer; and p has received
- the Proposal message v for round r, height h, along with all the block parts, from q,
Prevotemessages from 2f + 1 validators’ voting power for round r, height h, prevoting for the same block id(v),
then p’s Tenderdash locks v and sends a Precommit message in the following way
- p’s Tenderdash sets lockedValue and validValue to v, and sets lockedRound and validRound to r
- p’s Tenderdash calls
RequestExtendVotewith id(v) (RequestExtendVote.hash). The call is synchronous. - The Application optionally returns an array of bytes,
ResponseExtendVote.extension, which is not interpreted by Tenderdash. - p’s Tenderdash includes
ResponseExtendVote.extensionin a field of type CanonicalVoteExtension, it then populates the other fields in CanonicalVoteExtension, and signs the populated data structure. - p’s Tenderdash constructs and signs the CanonicalVote structure.
- p’s Tenderdash constructs the Precommit message (i.e. Vote structure) using CanonicalVoteExtension and CanonicalVote.
- p’s Tenderdash broadcasts the Precommit message.
In the cases when p’s Tenderdash is to broadcast precommit nil messages (either 2f+1 prevote nil messages received,
or timeoutPrevote triggered), p’s Tenderdash does not call RequestExtendVote and will not include
a CanonicalVoteExtension field in the precommit nil message.
Fields
hash: Vec<u8>The header hash of the proposed block that the vote extensions is to refer to.
height: i64Height of the proposed block (for sanity check).
round: i32// Round number for the block.