pub struct RequestFinalizeBlock {
pub commit: Option<CommitInfo>,
pub misbehavior: Vec<Misbehavior>,
pub hash: Vec<u8>,
pub height: i64,
pub round: i32,
pub block: Option<Block>,
pub block_id: Option<BlockId>,
}Expand description
Finalize newly decided block.
Usage
- Contains the fields of the newly decided block.
- The height and timestamp values match the values from the header of the proposed block.
- The Application can use
RequestFinalizeBlock.decided_last_commitandRequestFinalizeBlock.byzantine_validatorsto determine rewards and punishments for the validators. - The application must execute the transactions in full, in the order they appear in
RequestFinalizeBlock.txs, before returning control to Tenderdash. Alternatively, it can commit the candidate state corresponding to the same block previously executed viaPrepareProposalorProcessProposal. - If ProcessProposal for the same arguments have succeeded, FinalizeBlock MUST always succeed.
- Application is expected to persist its state at the end of this call, before returning
ResponseFinalizeBlock. - Later calls to
Querycan return proofs about the application state anchored in this Merkle root hash. - Use
ResponseFinalizeBlock.retain_heightwith caution! If all nodes in the network remove historical blocks then this data is permanently lost, and no new nodes will be able to join the network and bootstrap. Historical blocks may also be required for other purposes, e.g. auditing, replay of non-persisted heights, light client verification, and so on. - Just as
ProcessProposal, the implementation ofFinalizeBlockMUST be deterministic, since it is making the Application’s state evolve in the context of state machine replication. - Currently, Tenderdash will fill up all fields in
RequestFinalizeBlock, even if they were already passed on to the Application viaRequestPrepareProposalorRequestProcessProposal. If the Application is in same-block execution mode, it applies the right candidate state here (rather than executing the whole block). In this case the Application disregards all parameters inRequestFinalizeBlockexceptRequestFinalizeBlock.hash.
Fields
commit: Option<CommitInfo>Info about the current commit
misbehavior: Vec<Misbehavior>List of information about validators that acted incorrectly.
hash: Vec<u8>The block header’s hash. Present for convenience (can be derived from the block header).
height: i64The height of the finalized block.
round: i32Round number for the block
block: Option<Block>The block that was finalized
block_id: Option<BlockId>The block ID that was finalized